@@ -16,11 +16,13 @@ validate_csquares <- function(x) {
       x = "'x' is not of class 'csquares'",
       i = "Create a csquares object first with 'new_csquare' or 'as_csquares'"
     ))
-  x <- if(inherits(x, "character")) {
+  x <- if(inherits(x, c("character", "vctrs_vctr"))) {
     x
   } else {
     x[[attributes(x)$csquares_col]]
   }
-  check <- .csquares_to_coords(x)
-  all(check$check1 & check$check2 & check$check3 & check$check4)
+  strsplit(x, "[|]") |>
+    lapply(.check_csquare_validity) |>
+    unlist() |>
+    all()
 }
\ No newline at end of file
